import { DeviceType } from '@ucap-webmessenger/core';
import {
  APIRequest,
  APIResponse,
  APIEncoder,
  APIDecoder,
  ParameterUtil
} from '@ucap-webmessenger/api';

export interface UrlInfoRequest extends APIRequest {
  deviceType: DeviceType;
  loginId?: string;
}

export interface UrlInfoResponse extends APIResponse {
  portCheckUrl?: string;
  messageUrl?: string;
  messageUrl2?: string;
  passwordUrl?: string;
  planUrl?: string;
  planUrl2?: string;
  vocUrl?: string;
  confUrl?: string;
  uprApiUrl?: string;
  uprSvcUrl?: string;
  uprDownloadUrl?: string;
  synapViewUrl?: string;
}

export interface DaesangUrlInfoResponse extends UrlInfoResponse {
  webLink: WebLink[];
  webLinkAllowedList: string[];
}
export interface WebLink {
  key: string;
  title: string;
  url: string;
}

const urlInfoEncodeMap = {
  deviceType: 'p_device_type',
  loginId: 'p_user_id'
};

export const encodeUrlInfo: APIEncoder<UrlInfoRequest> = (
  req: UrlInfoRequest
) => {
  return ParameterUtil.encode(urlInfoEncodeMap, req);
};

export const decodeUrlInfo: APIDecoder<UrlInfoResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,
    portCheckUrl: res.PortCheckURL,
    messageUrl: res.MsgURL,
    messageUrl2: res.MsgURL2,
    passwordUrl: res.PasswordURL,
    planUrl: res.PlanURL,
    planUrl2: res.PlanURL2,
    vocUrl: res.VocURL,
    confUrl: res.ConfURL,
    uprApiUrl: res.UprApiURL,
    uprSvcUrl: res.UprSvcURL,
    uprDownloadUrl: res.UprDownloadURL,
    synapViewUrl: res.SynapViewURL
  } as UrlInfoResponse;
};
export const decodeUrlInfoDaesang: APIDecoder<DaesangUrlInfoResponse> = (
  res: any
) => {
  const webLink: WebLink[] = [];

  if (!!res.WebLinkWebhard) {
    const arr = res.WebLinkWebhard.split(',');
    webLink.push({
      key: 'WebLinkWebhard',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkDsp) {
    const arr = res.WebLinkDsp.split(',');
    webLink.push({
      key: 'WebLinkDsp',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkSms) {
    const arr = res.WebLinkSms.split(',');
    webLink.push({
      key: 'WebLinkSms',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkConf) {
    const arr = res.WebLinkConf.split(',');
    webLink.push({
      key: 'WebLinkConf',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkEp) {
    const arr = res.WebLinkEp.split(',');
    webLink.push({
      key: 'WebLinkEp',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkSop) {
    const arr = res.WebLinkSop.split(',');
    webLink.push({
      key: 'WebLinkSop',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkSom) {
    const arr = res.WebLinkSom.split(',');
    webLink.push({
      key: 'WebLinkSom',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkElephant) {
    const arr = res.WebLinkElephant.split(',');
    webLink.push({
      key: 'WebLinkElephant',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkItsvcdesk) {
    const arr = res.WebLinkItsvcdesk.split(',');
    webLink.push({
      key: 'WebLinkItsvcdesk',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkUrgntNews) {
    const arr = res.WebLinkUrgntNews.split(',');
    webLink.push({
      key: 'WebLinkUrgntNews',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkMailCnt) {
    const arr = res.WebLinkMailCnt.split(',');
    webLink.push({
      key: 'WebLinkMailCnt',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkMail) {
    const arr = res.WebLinkMail.split(',');
    webLink.push({
      key: 'WebLinkMail',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkPaymentCnt) {
    const arr = res.WebLinkPaymentCnt.split(',');
    webLink.push({
      key: 'WebLinkPaymentCnt',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkPayment) {
    const arr = res.WebLinkPayment.split(',');
    webLink.push({
      key: 'WebLinkPayment',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }
  if (!!res.WebLinkChgPassword) {
    const arr = res.WebLinkChgPassword.split(',');
    webLink.push({
      key: 'WebLinkChgPassword',
      title: arr.length > 1 ? arr[0] : '',
      url: arr.length > 1 ? arr[1] : arr[0]
    });
  }

  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,
    portCheckUrl: res.PortCheckURL,
    messageUrl: res.MsgURL,
    messageUrl2: res.MsgURL2,
    passwordUrl: res.PasswordURL,
    planUrl: res.PlanURL,
    planUrl2: res.PlanURL2,
    vocUrl: res.VocURL,
    confUrl: res.ConfURL,
    uprApiUrl: res.UprApiURL,
    uprSvcUrl: res.UprSvcURL,
    uprDownloadUrl: res.UprDownloadURL,
    synapViewUrl: res.SynapViewURL,

    webLink,
    webLinkAllowedList: res.WebLinkAllowedList.split(',')
  } as DaesangUrlInfoResponse;
};
